@@ -3,7 +3,15 @@
 #' @importFrom effectsize ranktransform
 #' @importFrom parameters model_parameters
 #' @keywords internal
-.cor_test_bayes <- function(data, x, y, ci = 0.95, method = "pearson", bayesian_prior = "medium", bayesian_ci_method = "hdi", bayesian_test = c("pd", "rope", "bf"), ...) {
+.cor_test_bayes <- function(data,
+                            x,
+                            y,
+                            ci = 0.95,
+                            method = "pearson",
+                            bayesian_prior = "medium",
+                            bayesian_ci_method = "hdi",
+                            bayesian_test = c("pd", "rope", "bf"),
+                            ...) {
   if (!requireNamespace("BayesFactor")) {
     stop("This function needs `BayesFactor` to be installed. Please install by running `install.packages('BayesFactor')`.")
   }
@@ -23,7 +31,18 @@
     method <- "Bayesian Pearson"
   }
 
-  out <- .cor_test_bayes_base(x, y, var_x, var_y, ci = ci, bayesian_prior = bayesian_prior, bayesian_ci_method = bayesian_ci_method, bayesian_test = bayesian_test, ...)
+  out <-
+    .cor_test_bayes_base(
+      x,
+      y,
+      var_x,
+      var_y,
+      ci = ci,
+      bayesian_prior = bayesian_prior,
+      bayesian_ci_method = bayesian_ci_method,
+      bayesian_test = bayesian_test,
+      ...
+    )
 
   # Add method
   out$Method <- method
@@ -32,7 +51,16 @@
 
 
 #' @keywords internal
-.cor_test_bayes_base <- function(x, y, var_x, var_y, ci = 0.95, bayesian_prior = "medium", bayesian_ci_method = "hdi", bayesian_test = c("pd", "rope", "bf"), method = "pearson", ...) {
+.cor_test_bayes_base <- function(x,
+                                 y,
+                                 var_x,
+                                 var_y,
+                                 ci = 0.95,
+                                 bayesian_prior = "medium",
+                                 bayesian_ci_method = "hdi",
+                                 bayesian_test = c("pd", "rope", "bf"),
+                                 method = "pearson",
+                                 ...) {
   if (!requireNamespace("BayesFactor")) {
     stop("This function needs `BayesFactor` to be installed. Please install by running `install.packages('BayesFactor')`.")
   }
@@ -40,7 +68,15 @@
   if (x == y) {
     # Avoid error in the case of perfect correlation
     rez <- BayesFactor::correlationBF(rnorm(1000), rnorm(1000), rscale = bayesian_prior)
-    params <- parameters::model_parameters(rez, ci_method = bayesian_ci_method, test = bayesian_test, rope_range = c(-0.1, 0.1), rope_ci = 1, ...)
+    params <-
+      parameters::model_parameters(
+        rez,
+        ci_method = bayesian_ci_method,
+        test = bayesian_test,
+        rope_range = c(-0.1, 0.1),
+        rope_ci = 1,
+        ...
+      )
     if ("Median" %in% names(params)) params$Median <- 1
     if ("Mean" %in% names(params)) params$Mean <- 1
     if ("MAP" %in% names(params)) params$MAP <- 1
@@ -53,7 +89,15 @@
     if ("BF" %in% names(params)) params$BF <- Inf
   } else {
     rez <- BayesFactor::correlationBF(var_x, var_y, rscale = bayesian_prior)
-    params <- parameters::model_parameters(rez, ci_method = bayesian_ci_method, test = bayesian_test, rope_range = c(-0.1, 0.1), rope_ci = 1, ...)
+    params <-
+      parameters::model_parameters(
+        rez,
+        ci_method = bayesian_ci_method,
+        test = bayesian_test,
+        rope_range = c(-0.1, 0.1),
+        rope_ci = 1,
+        ...
+      )
   }
 
   # Rename coef
