@@ -21,6 +21,7 @@ cor_to_ci <- function(cor, n, ci = 0.95, method = "pearson", correction = "fiell
 
 
 # Kendall -----------------------------------------------------------------
+#' @importFrom stats qnorm
 .cor_to_ci_kendall <- function(cor, n, ci = 0.95, correction = "fieller", ...) {
   # by @tsbaguley (https://rpubs.com/seriousstats/616206)
 
@@ -30,7 +31,7 @@ cor_to_ci <- function(cor, n, ci = 0.95, method = "pearson", correction = "fiell
     tau.se <- 1 / (n - 3)^0.5
   }
 
-  moe <- qnorm(1 - (1 - ci) / 2) * tau.se
+  moe <- stats::qnorm(1 - (1 - ci) / 2) * tau.se
   zu <- atanh(cor) + moe
   zl <- atanh(cor) - moe
 
@@ -54,7 +55,7 @@ cor_to_ci <- function(cor, n, ci = 0.95, method = "pearson", correction = "fiell
     zrs.se <- 1 / (n - 3)^0.5
   }
 
-  moe <- qnorm(1 - (1 - ci) / 2) * zrs.se
+  moe <- stats::qnorm(1 - (1 - ci) / 2) * zrs.se
 
   zu <- atanh(cor) + moe
   zl <- atanh(cor) - moe
