@@ -14,7 +14,7 @@ summary.easycorrelation <- function(object, redundant = FALSE, stars = TRUE, ...
     object <- .add_redundant(object)
   }
 
-  target_col <- names(object)[names(object) %in% c("r", "rho", "tau", "Median")][1]
+  target_col <- names(object)[names(object) %in% c("r", "rho", "tau", "Median", "Dxy")][1]
   if (is.na(target_col)) {
     target_col <- names(object)[!names(object) %in% c("Parameter1", "Parameter2")][1]
   }
@@ -27,7 +27,8 @@ summary.easycorrelation <- function(object, redundant = FALSE, stars = TRUE, ...
   }
 
   # Transfer attributes
-  attributes(out) <- c(attributes(out), attributes(object)[!names(attributes(object)) %in% c("names", "row.names", "class", names(attributes(out)))])
+  attributes(out) <-
+    c(attributes(out), attributes(object)[!names(attributes(object)) %in% c("names", "row.names", "class", names(attributes(out)))])
   attr(out, "stars") <- stars
   attr(out, "redundant") <- redundant
   attr(out, "coefficient_name") <- target_col
